@@ -1,5 +1,5 @@
 #
-# $Id: Generate.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Generate.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
 #
 # address::generate Brik
 #
@@ -11,13 +11,17 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 14a5b315905e $',
       tags => [ qw(unstable address ipv4 routable reserved) ],
       attributes => {
-         output_directory => [ qw(directory) ],
+         datadir => [ qw(directory) ],
          file_count => [ qw(integer) ],
          ip_count => [ qw(integer) ],
       },
+      attributes_default => {
+         file_count => 1000,
+         ip_count => 0,
+      },
       commands => {
          ipv4_reserved_ranges => [ ],
          ipv4_private_ranges => [ ],
@@ -33,18 +37,6 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         output_directory => $self->global->datadir.'/address-generate',
-         file_count => 1000,
-         ip_count => 0,
-      },
-   };
-}
-
 sub brik_init {
    my $self = shift;
 
@@ -53,11 +45,7 @@ sub brik_init {
       `ulimit -n 2048`;
    }
 
-   if (! -d $self->output_directory) {
-      mkdir($self->output_directory);
-   }
-
-   return $self->SUPER::brik_init;
+   return $self->SUPER::brik_init(@_);
 }
 
 sub ipv4_reserved_ranges {
@@ -106,7 +94,7 @@ sub ipv4_routable_ranges {
 sub ipv4_generate_space {
    my $self = shift;
 
-   my $output_directory = $self->output_directory;
+   my $datadir = $self->datadir;
    my $file_count = $self->file_count;
    my $ip_count = $self->ip_count;
 
@@ -118,15 +106,15 @@ sub ipv4_generate_space {
    if ($n > 0) {
       for (0..$n) {
          my $file = sprintf("ip4-space-%03d.txt", $_);
-         open($new, '>', "$output_directory/$file")
-            or return $self->log->error("ipv4_generate_space: open: file [$output_directory/$file]: $!");
+         open($new, '>', "$datadir/$file")
+            or return $self->log->error("ipv4_generate_space: open: file [$datadir/$file]: $!");
          push @chunks, $new;
       }
    }
    else {
       my $file = sprintf("ip4-space.txt", $_);
-      open($new, '>', "$output_directory/$file")
-         or return $self->log->error("ipv4_generate_space: open: file [$output_directory/$file]: $!");
+      open($new, '>', "$datadir/$file")
+         or return $self->log->error("ipv4_generate_space: open: file [$datadir/$file]: $!");
       push @chunks, $new;
    }
 
