@@ -1,5 +1,5 @@
 #
-# $Id: Cwe.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Cwe.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
 #
 # database::cwe Brik
 #
@@ -11,14 +11,15 @@ use base qw(Metabrik::File::Fetch);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 14a5b315905e $',
       tags => [ qw(unstable cve cwe) ],
       attributes => {
+         datadir => [ qw(datadir) ],
          file => [ qw(file) ],
          xml => [ qw($xml_data) ],
       },
       attributes_default => {
-         file => "/tmp/2000.xml",
+         file => '2000.xml',
       },
       commands => {
          update => [ ],
@@ -32,26 +33,10 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   my $dir = $self->global->datadir.'/database-cwe';
-   if (! -d $dir) {
-      mkdir($dir)
-         or return $self->log->error("brik_use_properties: mkdir for dir [$dir] failed");
-   }
-
-   return {
-      attributes_default => {
-         file => $dir.'/2000.xml',
-      },
-   };
-}
-
 sub update {
    my $self = shift;
 
-   my $datadir = $self->global->datadir.'/database-cwe';
+   my $datadir = $self->datadir;
 
    my $uri = 'http://cwe.mitre.org/data/xml/views/2000.xml.zip';
    my $file = "$datadir/2000.xml.zip";
@@ -72,17 +57,15 @@ sub load {
    my ($file) = @_;
 
    $file ||= $self->file;
-   if (! defined($file)) {
-      return $self->log->error($self->brik_help_run('load'));
-   }
-
    if (! -f $file) {
       return $self->log->error("load: file [$file] not found");
    }
 
+   my $datadir = $self->datadir;
+
    my $file_xml = Metabrik::File::Xml->new_from_brik($self);
 
-   my $xml = $file_xml->read($file);
+   my $xml = $file_xml->read($datadir.'/'.$file);
 
    return $self->xml($xml);
 }
