@@ -1,5 +1,5 @@
 #
-# $Id: Keystore.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Keystore.pm,v a3e23d615758 2015/01/05 06:48:41 gomor $
 #
 # database::keystore Brik
 #
@@ -11,13 +11,16 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: a3e23d615758 $',
       tags => [ qw(unstable database keystore) ],
       attributes => {
          db => [ qw(keystore_db) ],
       },
       commands => {
          search => [ qw(pattern) ],
+         decrypt => [ qw(keystore_db|OPTIONAL) ],
+         encrypt => [ qw($data) ],
+         save => [ qw($data keystore_db|OPTIONAL) ],
       },
       require_modules => {
          'Metabrik::Crypto::Aes' => [ ],
@@ -37,13 +40,7 @@ sub search {
       return $self->log->error($self->brik_help_run('search'));
    }
 
-   my $read = $self->read($self->db)
-      or return $self->log->error("search: read failed");
-
-   my $crypto_aes = Metabrik::Crypto::Aes->new_from_brik($self);
-
-   my $decrypted = $crypto_aes->decrypt($read)
-      or return $self->log->error("search: decrypt failed");
+   my $decrypted = $self->decrypt;
 
    my @results = ();
    my @lines = split(/\n/, $decrypted);
@@ -54,6 +51,58 @@ sub search {
    return \@results;
 }
 
+sub decrypt {
+   my $self = shift;
+   my ($db) = @_;
+
+   $db ||= $self->db;
+   if (! defined($db)) {
+      return $self->log->error($self->brik_help_set('db'));
+   }
+
+   my $read = $self->read($db)
+      or return $self->log->error("decrypt: read failed");
+
+   my $crypto_aes = Metabrik::Crypto::Aes->new_from_brik($self);
+
+   my $decrypted = $crypto_aes->decrypt($read)
+      or return $self->log->error("decrypt: decrypt failed");
+
+   return $decrypted;
+}
+
+sub encrypt {
+   my $self = shift;
+   my ($data) = @_;
+
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('encrypt'));
+   }
+
+   my $crypto_aes = Metabrik::Crypto::Aes->new_from_brik($self);
+
+   my $encrypted = $crypto_aes->encrypt($data)
+      or return $self->log->error("encrypt: encrypt failed");
+
+   return $encrypted;
+}
+
+sub save {
+   my $self = shift;
+   my ($data, $db) = @_;
+
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('save'));
+   }
+
+   $db ||= $self->db;
+
+   $self->write($data, $db)
+      or return $self->log->error("save: write failed");
+
+   return $db;
+}
+
 1;
 
 __END__
