@@ -1,5 +1,5 @@
 #
-# $Id: Compress.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Compress.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
 #
 # file::zip brik
 #
@@ -11,15 +11,15 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 14a5b315905e $',
       tags => [ qw(unstable compress unzip gunzip uncompress) ],
       attributes => {
+         datadir => [ qw(directory) ],
          input => [ qw(file) ],
          output => [ qw(file) ],
-         destdir => [ qw(directory) ],
       },
       commands => {
-         unzip => [ qw(input|OPTIONAL destdir|OPTIONAL) ],
+         unzip => [ qw(input|OPTIONAL datadir|OPTIONAL) ],
          gunzip => [ qw(input|OPTIONAL output|OPTIONAL) ],
       },
       require_binaries => {
@@ -29,31 +29,18 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         destdir => $self->global->datadir,
-      },
-   };
-}
-
 sub unzip {
    my $self = shift;
-   my ($input, $destdir) = @_;
+   my ($input, $datadir) = @_;
 
    $input ||= $self->input;
    if (! defined($input)) {
       return $self->log->error($self->brik_help_set('input'));
    }
 
-   $destdir ||= $self->destdir;
-   if (! defined($destdir)) {
-      return $self->log->error($self->brik_help_set('destdir'));
-   }
+   $datadir ||= $self->datadir;
 
-   my $cmd = "unzip -o $input -d $destdir/";
+   my $cmd = "unzip -o $input -d $datadir/";
 
    return $self->system($cmd);
 }
