@@ -1,5 +1,5 @@
 #
-# $Id: Read.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Read.pm,v e9c15c7beddf 2015/01/21 07:05:57 gomor $
 #
 # file::read Brik
 #
@@ -11,22 +11,27 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: e9c15c7beddf $',
       tags => [ qw(unstable file) ],
       attributes => {
          input => [ qw(file) ],
          encoding => [ qw(utf8|ascii) ],
          fd => [ qw(file_descriptor) ],
          as_array => [ qw(0|1) ],
+         eof => [ qw(0|1) ],
+         count => [ qw(count) ],
       },
       attributes_default => {
          as_array => 0,
+         eof => 0,
+         count => 1,
       },
       commands => {
          open => [ qw(file|OPTIONAL) ],
          close => [ ],
          readall => [ ],
          read_until_blank_line => [ ],
+         read_line => [ qw(count|OPTIONAL) ],
       },
    };
 }
@@ -91,6 +96,7 @@ sub readall {
          chomp;
          push @out, $_;
       }
+      $self->eof(1);
       return \@out;
    }
    else {
@@ -98,6 +104,7 @@ sub readall {
       while (<$fd>) {
          $out .= $_;
       }
+      $self->eof(1);
       return $out;
    }
 
@@ -119,6 +126,9 @@ sub read_until_blank_line {
          chomp;
          push @out, $_;
       }
+      if (eof($fd)) {
+         $self->eof(1);
+      }
       return \@out;
    }
    else {
@@ -127,6 +137,52 @@ sub read_until_blank_line {
          last if /^\s*$/;
          $out .= $_;
       }
+      if (eof($fd)) {
+         $self->eof(1);
+      }
+      return $out;
+   }
+
+   return;
+}
+
+sub read_line {
+   my $self = shift;
+   my ($count) = @_;
+
+   my $fd = $self->fd;
+   if (! defined($fd)) {
+      return $self->log->error($self->brik_help_run('open'));
+   }
+
+   $count ||= $self->count;
+
+   if ($self->as_array) {
+      my @out = ();
+      my $this = 1;
+      while (<$fd>) {
+         chomp;
+         push @out, $_;
+         last if $this == $count;
+         $count++;
+      }
+      if (eof($fd)) {
+         $self->eof(1);
+      }
+      return \@out;
+   }
+   else {
+      my $out = '';
+      my $this = 1;
+      while (<$fd>) {
+         last if /^\s*$/;
+         $out .= $_;
+         last if $this == $count;
+         $count++;
+      }
+      if (eof($fd)) {
+         $self->eof(1);
+      }
       return $out;
    }
 
