@@ -1,5 +1,5 @@
 #
-# $Id: Countrycode.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Countrycode.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
 #
 # iana::countrycode Brik
 #
@@ -11,12 +11,17 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 14a5b315905e $',
       tags => [ qw(unstable iana countrycode cc) ],
       attributes => {
+         datadir => [ qw(datadir) ],
          input => [ qw(file) ],
          output => [ qw(file) ],
       },
+      attributes_default => {
+         input => 'country-codes.csv',
+         output => 'country-codes.csv',
+      },
       commands => {
          update => [ ],
          save => [ qw($csv_struct output|OPTIONAL) ],
@@ -29,23 +34,6 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   my $dir = $self->global->datadir.'/iana-countrycode';
-   if (! -d $dir) {
-      mkdir($dir)
-         or return $self->log->error("brik_use_properties: mkdir failed for dir [$dir]");
-   }
-
-   return {
-      attributes_default => {
-         input => $dir.'/country-codes.csv',
-         output => $dir.'/country-codes.csv',
-      },
-   };
-}
-
 sub country_code_types {
    my $self = shift;
    my ($data) = @_;
@@ -118,18 +106,18 @@ sub save {
    }
 
    $output ||= $self->output;
-   if (! defined($output)) {
-      return $self->log->error($self->brik_help_run('save'));
-   }
+
+   my $datadir = $self->datadir;
 
    my $file_csv = Metabrik::File::Csv->new_from_brik($self);
    $file_csv->overwrite(1);
    $file_csv->encoding('utf8');
 
-   $file_csv->write($data, $output)
+   my $output_file = $datadir.'/'.$output;
+   $file_csv->write($data, $output_file)
       or return $self->log->error("save: write failed");
 
-   return $output;
+   return $output_file;
 }
 
 sub load {
@@ -137,17 +125,16 @@ sub load {
    my ($input) = @_;
 
    $input ||= $self->input;
-   if (! defined($input)) {
-      return $self->log->error($self->brik_help_set('input'));
-   }
    if (! -f $input) {
       return $self->log->error("load: file [$input] not found");
    }
 
+   my $datadir = $self->datadir;
+
    my $file_csv = Metabrik::File::Csv->new_from_brik($self);
    $file_csv->first_line_is_header(1);
 
-   my $csv = $file_csv->read($input);
+   my $csv = $file_csv->read($datadir.'/'.$input);
 
    return $csv;
 }
