@@ -1,5 +1,5 @@
 #
-# $Id: Service.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Service.pm,v f0806c23ff74 2015/01/25 18:03:03 gomor $
 #
 # lookup::service Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik::File::Csv);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable iana) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: f0806c23ff74 $',
+      tags => [ qw(unstable lookup service iana) ],
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(input) ],
@@ -32,8 +30,7 @@ sub brik_properties {
          from_string => [ qw(service_string) ],
       },
       require_modules => {
-         'Metabrik::Client::Www' => [ ],
-         'Metabrik::File::Compress' => [ ],
+         'Metabrik::File::Fetch' => [ ],
          'Metabrik::File::Text' => [ ],
       },
    };
@@ -44,34 +41,13 @@ sub update {
    my ($output) = @_;
 
    my $url = 'http://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.csv';
+   my ($file) = $self->input;
 
-   my $input = $self->input;
-   my $datadir = $self->datadir;
-   $output ||= $input;
+   $output ||= $self->datadir.'/'.$file;
 
-   my $cw = Metabrik::Client::Www->new_from_brik_init($self) or return;
-   my $files = $cw->mirror($url, "$output.gz", $datadir) or return;
-
-   # If files were modified, we uncompress and save
-   if (@$files > 0) {
-      my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
-      $fc->uncompress($datadir."/$output.gz", $output, $datadir) or return;
-
-      # We have to rewrite the CSV file, cause some entries are multiline.
-      my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
-      $ft->overwrite(1);
-      $ft->append(0);
-      my $text = $ft->read($datadir.'/'.$output) or return;
-
-      # Some lines are split on multi-lines, we put into a single line
-      # for each record.
-      my @new = split(/\r\n/, $text);
-      for (@new) {
-         s/\n/ /g;
-      }
-
-      $ft->write(\@new, $output);
-   }
+   my $ff = Metabrik::File::Fetch->new_from_brik_init($self) or return;
+   $ff->get($url, $output)
+      or return $self->log->error("update: get failed");
 
    return $output;
 }
@@ -81,9 +57,12 @@ sub load {
    my ($input) = @_;
 
    $input ||= $self->datadir.'/'.$self->input;
-   $self->brik_help_run_file_not_found('load', $input) or return;
+   if (! -f $input) {
+      return $self->log->error("load: file [$input] not found");
+   }
 
-   my $data = $self->read($input) or return;
+   my $data = $self->read($input)
+      or return $self->log->error("load: read failed");
 
    return $self->_load($data);
 }
@@ -92,7 +71,9 @@ sub from_dec {
    my $self = shift;
    my ($dec) = @_;
 
-   $self->brik_help_run_undef_arg('from_dec', $dec) or return;
+   if (! defined($dec)) {
+      return $self->log->error($self->brik_help_run('from_dec'));
+   }
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -106,14 +87,16 @@ sub from_dec {
    }
 
    # No match
-   return 'undef';
+   return;
 }
 
 sub from_hex {
    my $self = shift;
    my ($hex) = @_;
 
-   $self->brik_help_run_undef_arg('from_hex', $hex) or return;
+   if (! defined($hex)) {
+      return $self->log->error($self->brik_help_run('from_hex'));
+   }
 
    my $dec = hex($hex);
 
@@ -124,7 +107,9 @@ sub from_string {
    my $self = shift;
    my ($string) = @_;
 
-   $self->brik_help_run_undef_arg('from_string', $string) or return;
+   if (! defined($string)) {
+      return $self->log->error($self->brik_help_run('from_string'));
+   }
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -139,6 +124,10 @@ sub from_string {
          $self->log->verbose("from_string: match with [$service]");
          push @match, $this->{'Port Number'}.'/'.$this->{'Transport Protocol'};
       }
+      elsif ($service =~ /$string/i) {
+         $self->log->verbose("from_string: match with [$service]");
+         push @match, $this->{'Port Number'}.'/'.$this->{'Transport Protocol'};
+      }
    }
 
    return \@match;
@@ -154,7 +143,7 @@ Metabrik::Lookup::Service - lookup::service Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
