@@ -1,5 +1,5 @@
 #
-# $Id: Nikto.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Nikto.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
 #
 # network::nikto Brik
 #
@@ -11,9 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 14a5b315905e $',
       tags => [ qw(unstable network security scanner nikto) ],
       attributes => {
+         datadir => [ qw(datadir) ],
          uri => [ qw(uri) ],
          args => [ qw(nikto_arguments) ],
          output => [ qw(output_file.html) ],
@@ -29,17 +30,6 @@ sub brik_properties {
    };
 }
 
-sub brik_init {
-   my $self = shift;
-
-   my $dir = $self->global->datadir.'/nikto';
-   if (! -d $dir) {
-      mkdir($dir);
-   }
-
-   return $self->SUPER::brik_init(@_);
-}
-
 sub _nikto_parse {
    my $self = shift;
    my ($cmd, $result) = @_;
@@ -77,14 +67,14 @@ sub start {
 
    my $args = $self->args;
 
-   my $datadir = $self->global->datadir;
+   my $datadir = $self->datadir;
  
    my $cmd = "nikto -host $host -port $port -root $path $args";
    if ($use_ssl) {
       $cmd .= " -ssl";
    }
 
-   $cmd .= " -output $datadir/nikto/$output 2>&1 | tee $datadir/nikto/$output.txt";
+   $cmd .= " -output $datadir/$output 2>&1 | tee $datadir/$output.txt";
 
    my $result = `$cmd`; 
 
