@@ -1,5 +1,5 @@
 #
-# $Id: Module.pm 360 2014-11-16 14:52:06Z gomor $
+# $Id: Module.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
 #
 # perl::module Brik
 #
@@ -7,18 +7,15 @@ package Metabrik::Perl::Module;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 360 $',
+      revision => '$Revision: eff9afda3723 $',
       tags => [ qw(unstable perl module install cpan) ],
       commands => {
          install => [ qw(Module) ],
       },
-      require_used => {
-         'shell::command' => [ ],
-      },
       require_binaries => {
          'metabrik-cpanm' => [ ],
       },
@@ -34,12 +31,10 @@ sub install {
    }
 
    if ($module !~ /^[A-Za-z0-9:]+$/) {
-      return $self->log->error("install: module [$module]: invalid format");
+      return $self->log->error("install: invalid format for module [$module]");
    }
 
-   my $context = $self->context;
-
-   return $context->run('shell::command', 'system', "metabrik-cpanm $module");
+   return $self->system("metabrik-cpanm $module");
 }
 
 1;
@@ -52,7 +47,7 @@ Metabrik::Perl::Module - perl::module Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
