@@ -1,5 +1,5 @@
 #
-# $Id: Http.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Http.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
 #
 # server::http Brik
 #
@@ -11,12 +11,12 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 14a5b315905e $',
       tags => [ qw(unstable server http) ],
       attributes => {
+         datadir => [ qw(datadir) ],
          hostname => [ qw(listen_hostname) ],
          port => [ qw(listen_port) ],
-         root_directory => [ qw(root_directory) ],
          _http => [ qw(INTERNAL) ],
       },
       attributes_default => {
@@ -24,7 +24,7 @@ sub brik_properties {
          port => 8888,
       },
       commands => {
-         start => [ qw(listen_hostname|OPTIONAL listen_port|OPTIONAL root_directory|OPTIONAL) ],
+         start => [ qw(listen_hostname|OPTIONAL listen_port|OPTIONAL datadir|OPTIONAL) ],
       },
       require_modules => {
          'HTTP::Server::Brick' => [ ],
@@ -32,24 +32,9 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         root_directory => $self->global->datadir.'/http',
-      },
-   };
-}
-
 sub brik_init {
    my $self = shift;
 
-   if (! -d $self->root_directory) {
-      mkdir($self->root_directory)
-         or return $self->log->error("brik_init: cannot create directory");
-   }
-
    my $restore = $SIG{INT};
 
    $SIG{INT} = sub {
@@ -59,7 +44,7 @@ sub brik_init {
       return 1;
    };
 
-   return $self->SUPER::brik_init;
+   return $self->SUPER::brik_init(@_);
 }
 
 sub start {
@@ -68,7 +53,7 @@ sub start {
 
    $hostname ||= $self->hostname;
    $port ||= $self->port;
-   $root ||= $self->root_directory;
+   $root ||= $self->datadir;
 
    my $http = HTTP::Server::Brick->new(
       port => $port,
