@@ -1,5 +1,5 @@
 #
-# $Id: Password.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Password.pm,v 7ab98dcb8e17 2015/01/07 06:31:04 gomor $
 #
 # string::password Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 7ab98dcb8e17 $',
       tags => [ qw(unstable password random) ],
       attributes => {
          charset => [ qw($character_list) ],
@@ -24,20 +24,24 @@ sub brik_properties {
          count => 5,
       },
       commands => {
-         generate => [ ],
+         generate => [ qw(length|OPTIONAL count|OPTIONAL) ],
+         prompt => [ ],
       },
       require_modules => {
          'String::Random' => [ ],
+         'Term::ReadPassword' => [ ],
       },
    };
 }
 
 sub generate {
    my $self = shift;
+   my ($length, $count) = @_;
+
+   $length ||= $self->length;
+   $count ||= $self->count;
 
    my $charset = $self->charset;
-   my $length = $self->length;
-   my $count = $self->count;
 
    my $rand = String::Random->new;
    $rand->{A} = $charset;
@@ -50,6 +54,21 @@ sub generate {
    return \@passwords;
 }
 
+sub prompt {
+   my $self = shift;
+
+   my $password;
+   while (1) {
+      my $this = Term::ReadPassword::read_password('password: ');
+      if (defined($this)) {
+         $password = $this;
+         last;
+      }
+   }
+
+   return $password;
+}
+
 1;
 
 __END__
