@@ -1,5 +1,5 @@
 #
-# $Id: Universal.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Universal.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
 #
 # time::universal Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable timezone) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: eff9afda3723 $',
+      tags => [ qw(time timezone) ],
       attributes => {
          timezone => [ qw(string) ],
       },
@@ -25,8 +23,6 @@ sub brik_properties {
          list_timezones => [ ],
          search_timezone => [ qw(string) ],
          localtime => [ qw(timezone|OPTIONAL) ],
-         today => [ ],
-         date => [ ],
       },
       require_modules => {
          'DateTime' => [ ],
@@ -36,8 +32,6 @@ sub brik_properties {
 }
 
 sub list_timezones {
-   my $self = shift;
-
    return DateTime::TimeZone->all_names;
 }
 
@@ -45,7 +39,9 @@ sub search_timezone {
    my $self = shift;
    my ($pattern) = @_;
 
-   $self->brik_help_run_undef_arg('search_timezone', $pattern) or return;
+   if (! defined($pattern)) {
+      return $self->log->error($self->brik_help_run('search_timezone'));
+   }
 
    my $list = $self->list_timezones;
 
@@ -64,7 +60,9 @@ sub localtime {
    my ($timezone) = @_;
 
    $timezone ||= $self->timezone;
-   $self->brik_help_run_undef_arg('localtime', $timezone) or return;
+   if (! defined($timezone)) {
+      return $self->log->error($self->brik_help_set('timezone'));
+   }
 
    my $time = {};
    if (ref($timezone) eq 'ARRAY') {
@@ -85,23 +83,6 @@ sub localtime {
    return $time;
 }
 
-sub today {
-   my $self = shift;
-
-   my @a = CORE::localtime();
-   my $y = $a[5] + 1900;
-   my $m = $a[4] + 1;
-   my $d = $a[3];
-
-   return "$y-$m-$d";
-}
-
-sub date {
-   my $self = shift;
-
-   return CORE::localtime()."";
-}
-
 1;
 
 __END__
@@ -112,7 +93,7 @@ Metabrik::Time::Universal - time::universal Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
